@@ -62,15 +62,20 @@ Backtrace::Backtrace () noexcept {
 Backtrace::~Backtrace() {}
 
 iptr<BacktraceInfo> Backtrace::get_backtrace_info() const noexcept {
-    std::vector<StackframePtr> frames_info;
-    for(auto frame_ptr: buffer) {
-        StackframePtr frame;
-        for(auto it = frame_producers.rbegin(); it != frame_producers.rend() && !frame; ++it) {
-            frame = (*it)(frame_ptr);
-        }
-        if (frame) frames_info.emplace_back(std::move(frame));
+    StackFrames frames;
+    std::vector<BacktraceBackendSP> backends;
+    for(auto it = frame_producers.rbegin(); it != frame_producers.rend(); ++it) {
+        auto backend = (*it)(*this);
+        if (backend) backends.emplace_back(std::move(backend));
     }
-    return iptr<BacktraceInfo>(new BacktraceInfo(std::move(frames_info)));
+
+    for (size_t i = 0; i < buffer.size(); ++i) {
+        bool done = false;
+        for (size_t j = 0; j < backends.size() && !done; ++j) {
+            done = backends[j]->produce_frame(frames, i);
+        }
+    }
+    return iptr<BacktraceInfo>(new BacktraceInfo(std::move(frames)));
 }
 
 string Backtrace::dump_trace() noexcept {
